@@ -1,4 +1,4 @@
-# Copyright (c) 2009 Six Apart Ltd.
+# Copyright (c) 2009-2010 Six Apart Ltd.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -259,37 +259,37 @@ class User(typepad.User):
 
     @property
     def typepad_url(self):
-        try:
-            return self.links['alternate'].href
-        except (TypeError, KeyError):
-            # fail silently?
-            return None
+        import logging
+        logging.getLogger("typepadapp.models.users").warn(
+            'User.typepad_url is deprecated; use User.profile_page_url instead')
+        return self.profile_page_url
 
     @property
     def typepad_edit_url(self):
-        try:
-            return self.links['profile-edit-page'].href
-        except (TypeError, KeyError):
-            # fail silently?
-            return None
-
-    @property
-    def typepad_membership_management_url(self):
-        try:
-            return self.links['membership-management-page'].href
-        except (TypeError, KeyError):
-            # fail silently?
-            return None
+        import logging
+        logging.getLogger("typepadapp.models.users").warn(
+            'User.typepad_edit_url is deprecated; use User.profile_edit_page_url instead')
+        return self.profile_edit_page_url
 
     @property
     def typepad_frame_url(self):
-        return self.links['follow-frame-content'].href
+        import logging
+        logging.getLogger("typepadapp.models.users").warn(
+            'User.typepad_frame_url is deprecated; use User.follow_frame_content_url instead')
+        return self.follow_frame_content_url
 
     @property
     def userpic(self):
+        """Returns a URL for a userpic for the User.
+
+        The returned URL should be sized for a 50x50 square, but this
+        cannot be guaranteed. The img tag should be styled in a way
+        that bounds the presentation to 50 pixels square.
+
+        """
         try:
-            return self.links['rel__avatar']['width__50'].href
-        except (TypeError, KeyError):
+            return self.avatar_link.square(50).url
+        except AttributeError:
             pass
         try:
             return reverse('static-serve', kwargs={'path': settings.DEFAULT_USERPIC_PATH})
@@ -298,6 +298,29 @@ class User(typepad.User):
         return None
 
 
+class UserProfile(typepad.UserProfile):
+
+    @property
+    def is_superuser(self):
+        for admin in typepadapp.models.GROUP.admins():
+            if self.id == admin.target.id:
+                return True
+        return False
+
+    @property
+    def is_featured_member(self):
+        if settings.FEATURED_MEMBER is None: return False
+        return settings.FEATURED_MEMBER in (self.id,
+            self.preferred_username)
+
+    @property
+    def typepad_frame_url(self):
+        import logging
+        logging.getLogger("typepadapp.models.users").warn(
+            'UserProfile.typepad_frame_url is deprecated; use UserProfile.follow_frame_content_url instead')
+        return self.follow_frame_content_url
+
+
 ### Caching support
 
 if settings.FRONTEND_CACHING:
@@ -308,6 +331,7 @@ if settings.FRONTEND_CACHING:
         """Attempts to use a caching key of the user's username, if available."""
         return "objectcache:%s:%s" % (self.cache_namespace, self.preferred_username or self.url_id)
     User.cache_key = property(make_user_alias_cache_key)
+    UserProfile.cache_key = property(make_user_alias_cache_key)
 
     User.get_by_url_id = cache_object(User.get_by_url_id)
     user_invaldator = invalidate_rule(
@@ -315,6 +339,12 @@ if settings.FRONTEND_CACHING:
         signals=[signals.member_banned, signals.member_unbanned],
         name="user cache invalidation for member_banned, member_unbanned signals")
 
+    UserProfile.get_by_url_id = cache_object(UserProfile.get_by_url_id)
+    user_profile_invaldator = invalidate_rule(
+        key=lambda sender, instance=None, group=None, **kwargs: UserProfile.get_by_url_id(instance.preferred_username or instance.url_id),
+        signals=[signals.member_banned, signals.member_unbanned],
+        name="user profile cache invalidation for member_banned, member_unbanned signals")
+
     User.events = cache_link(User.events)
     user_events_invalidator = invalidate_rule(
         key=lambda sender, group=None, instance=None, **kwargs:
@@ -333,8 +363,8 @@ if settings.FRONTEND_CACHING:
         key=lambda sender, instance=None, group=None, **kwargs:
             instance and group and [instance.group_memberships(group),
                 instance.preferred_username and User.get_by_url_id(instance.preferred_username).group_memberships(group)],
-        signals=[signals.member_banned, signals.member_unbanned],
-        name="user membership invalidation for member_banned, member_unbanned signals")
+        signals=[signals.member_banned, signals.member_unbanned, signals.member_joined, signals.member_left],
+        name="user membership invalidation for member_banned, member_unbanned, member_joined, member_left signals")
 
     User.elsewhere_accounts = cache_link(User.elsewhere_accounts)
     # signals.profile_webhook
