@@ -1,4 +1,4 @@
-# Copyright (c) 2009 Six Apart Ltd.
+# Copyright (c) 2009-2010 Six Apart Ltd.
 # All rights reserved.
 #
 # Redistribution and use in source and binary forms, with or without
@@ -112,12 +112,19 @@ def authorize(request):
 
     # store the token key / secret in the database so we can recover
     # it later if the session expires
-    token, created = Token.objects.get_or_create(session_sync_token=request.GET['session_sync_token'], defaults={'key': access_token.key, 'secret': access_token.secret})
-    if not created:
+    token, created = Token.objects.get_or_create(
+        session_sync_token=request.GET['session_sync_token'],
+        defaults={'key': access_token.key, 'secret': access_token.secret}
+    )
+    if created:
+        # this is a new user or at least a new session sync token
+        signals.member_joined.send(sender=authorize, instance=authed_user,
+            group=request.group)
+    else:
+        # update token with current access token
         token.key = access_token.key
         token.secret = access_token.secret
         token.save()
-        signals.member_joined.send(sender=authorize, instance=authed_user, group=request.group)
 
     # oauth token in authed user session
     request.session['oauth_token'] = token
@@ -249,7 +256,7 @@ def logout(request):
     from django.contrib.auth import logout
     logout(request)
     # redirect to logout of typepad
-    url = request.application.signout_page
+    url = request.application.signout_url
     url = parameterize_url(url, { 'callback_url':
         request.build_absolute_uri(HOME_URL) })
     return http.HttpResponseRedirect(url)
